@@ -2,6 +2,7 @@ use std::collections::BTreeMap;
 
 use super::*;
 
+pub use machine::AWSMachineTemplate;
 pub use network::ClassicELBScheme;
 pub use network::NetworkSpec;
 pub use network::NetworkStatus;
@@ -11,6 +12,7 @@ pub use types::AZSelectionScheme;
 pub use types::Instance;
 
 mod impls;
+mod machine;
 mod network;
 mod tags;
 mod types;
